﻿using PizzeriaContracts.BindingModels;
using PizzeriaContracts.ViewModels;
using PizzeriaDataModels.Models;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace PizzeriaDatabaseImplement.models
{
    public class Implementer : IImplementerModel
    {
        public int Id { get; private set; }
        [Required]
        public string ImplementerFIO { get; private set; }
        [Required]
        public int WorkExperience { get; private set; }
        [Required]
        public int Qualification { get; private set; }
        [Required]
        public string Password { get; private set; }

        [ForeignKey("ImplementerId")]
        public virtual List<Order> Orders { get; set; } = new();
        public static Implementer? Create(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Implementer()
            {
                Id = model.Id,
                ImplementerFIO = model.ImplementerFIO,
                WorkExperience = model.WorkExperience,
                Qualification = model.Qualification,
                Password = model.Password
            };
        }
        public static Implementer Create(ImplementerViewModel model)
        {
            return new Implementer
            {
                Id = model.Id,
                ImplementerFIO = model.ImplementerFIO,
                WorkExperience = model.WorkExperience,
                Qualification = model.Qualification,
                Password = model.Password
            };
        }
        public void Update(ImplementerBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Id = model.Id;
            ImplementerFIO = model.ImplementerFIO;
            WorkExperience = model.WorkExperience;
            Qualification = model.Qualification;
            Password = model.Password;
        }
        public ImplementerViewModel GetViewModel => new()
        {
            Id = Id,
            ImplementerFIO = ImplementerFIO,
            WorkExperience = WorkExperience,
            Qualification = Qualification,
            Password = Password
        };
    }
}
